<?php
require_once('fpdf/fpdf.php');

// Create your class instance
$fpdf = new FPDF();
// Set up the default page margins for your PDF
// The parameters are margin left, margin top, margin right (units used are mm)
$fpdf->SetMargins(0, 0, 0);
// SetAutoPageBreak function will create a new page if our content exceeds the page limit. 0 stands for margin from bottom of the page before breaking.
$fpdf->SetAutoPageBreak(true, 0);
// AliasNbPages is optional if you want the ability to display page numbers on your PDF pages.
$fpdf->AliasNbPages();

// We need to define the path to where our font files are located. To add additional fonts from the default ones supplied see http://www.fpdf.org/makefont/)
define('FPDF_FONTPATH', 'font/');
// Setting up our fonts and styles - The first parameter is the string you will use in your code to access this font, the second is the style of the font you are setting (B = bold, I = italic, BI = Bold & Italic) and finally is the php file containing your font.
$fpdf->AddFont('Verdana', '','verdana.php'); // Add standard Arial
$fpdf->AddFont('Verdana', 'B', 'verdanab.php'); // Add bolded version of Arial
$fpdf->AddFont('Verdana', 'I', 'verdanai.php'); // Add italicised version of Arial

$fpdf->AddPage();

// Set font size
$fpdf->SetFontSize(10);
// Select our font family
$fpdf->SetFont('Verdana', '');

// First we add our Cell function
$fpdf->Cell(30, 6, 'Description', 0, 0, 'L', FALSE);
/* Parameters are as follows:
 56 - This is the width in mm that we set our Cell
6 - This is the height in mm
'Description' - Text to display inside the Cell
0 - This is for the border. 1 = border and 0 = no border.
0 - This is the position for our next Cell/MultiCell. 0 will fit the next cell in to the right of this one and 1 will fit the next cell underneath.
L - This is the alignment of our Cell. L = Left, R = Right and C = Centered.
FALSE - This is whether or not we want our Cell to have background fill colour.
*/

// Next we add our MultiCell.
$fpdf->MultiCell(100, 6, 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendis seiaculis quam nec nibh frin gilla euismod.Nam accumsan neque eget lorem scelerisque vestibulum.', 0, 'L');
// These parameters are the same as the Cell function, however the value 6 is referring to the height for each line rather than in total and the Parameter for where the next Cell is to be positioned is not in the MultiCell function - Cells will automatically appear below.

// First we set the style of our cell - (We have Verdana below - but this function is also for swapping between font families)
$fpdf->SetFont('Verdana', 'B'); // Make our text bold.
// Lets set our font colour - this is in the format of R,G,B
$fpdf->SetTextColor(255, 255, 255); // Set text to the colour white.
// If we want our Cell to have a background colour or a border we use the following:
$fpdf->SetFillColor(0, 0, 0); // Set background colour to black
$fpdf->SetDrawColor(31, 152, 152); // Set the border colour to Aqua
$fpdf->SetLineWidth(1); // Set our line width of our border to 1mm
// Now we output a Cell to display the above styles.
$fpdf->Cell(70, 6, 'This is white text on a black box', 1, 0, 'L', TRUE);
// Then for example if we wanted the next cell to have orange text we would change the text colour
$fpdf->SetTextColor(242, 154, 0);
$fpdf->Cell(80, 6, 'This is orange text on a black box', 1, 0, 'L', TRUE);

// Check where we are currently located on the page
$fpdf->GetX(); // Return how many mm we are from the left of the page.
$fpdf->GetY(); // Returns how many mm we are from the top of the page.

// Move to a new point on our page.
$fpdf->SetXY(50, 40); // This will move us 50mm from the left and 40mm from the top of our page. Functions SetX and SetY can be used for setting these points separately.
$fpdf->Cell(80, 6, 'This is where we have moved our XY position to', 0, 0, 'L');

$fpdf->Image('fpdf/image.jpg', 100, 60, 100, 80);
// The above parameters are: The image file path, The X position, The Y position, width, height. Note that the X and Y position are for where the top left hand corner sits on the page.

// So as we learnt above for styles, we will set our border's width and colour
$fpdf->SetDrawColor(234, 36, 227); // Hot Pink
$fpdf->SetLineWidth(2); // We will change the line width now to 2mm
$fpdf->Rect(5, 150, 200, 80, 'D');
// The first two parameters are setting where to begin drawing (X & Y). The second two are the width & height of our rectangle. D stands for draw - so this will display a rectangle with a border only. If this was F it would show a solid rectangle in a block fill colour (F = Fill). DF does both of these.

$fpdf->SetXY(190,290);
$fpdf->Cell(30, 4, 'Page ' . $fpdf->PageNo(), 0, 1);

$fpdf->Output('Filename.pdf', 'I');
// The first parameter is what we are naming our file. The second parameter is the destination of your file.
// 'I' - This outputs the file to the browser - the file name is what it will default to if 'Save As' is selected. 'D' will force the file to be downloaded. 'F' will save the PDF file locally (To do this you need to include the file path in the file name field also).

?>